@@ -8,20 +8,7 @@
 */
 
 #include "SearchFilePath.h"
-#include "DetectOS.h"
-#if defined LINUX_OS || defined Cygwin
-#include <unistd.h>
-#else
-#include <windows.h>
-#include <direct.h>
-#include <io.h>
-#ifndef F_OK
-#define F_OK 06
-#endif
-#ifndef W_OK
-#define W_OK 06
-#endif
-#endif
+#include "ExistFile.h"
 
 
 bool searchFilePath(std::string& full_path, const char* fname,
@@ -47,7 +34,7 @@ bool searchFilePath(std::string& full_path, const char* fname,
       }
     }
     std::string try_path = replaced + "/" + fname;
-    if (access(try_path.c_str(), F_OK) == 0) {
+    if (existFile(try_path.c_str())) {
       full_path = try_path;
       return true;
     }
